@@ -1,6 +1,6 @@
 package CatalystX::DebugFilter;
 BEGIN {
-  $CatalystX::DebugFilter::VERSION = '0.07';
+  $CatalystX::DebugFilter::VERSION = '0.08';
 }
 
 # ABSTRACT: Provides configurable filtering of data that is logged to the debug logs (and error screen)
@@ -87,8 +87,12 @@ sub _filter_request_params {
     foreach my $type (@types) {
         my $method = join '_', grep { $_ } $type, 'parameters';
         my $params = $req->$method;
-        next if !$params;
-        $is_filtered += _filter_hash_ref( $params, @filters );
+        next if !%$params;
+        my $copy = { %$params };
+        $is_filtered += _filter_hash_ref( $copy, @filters );
+        if($is_filtered){
+            $req->$method($copy);
+        }
     }
     return $is_filtered;
 }
@@ -166,7 +170,7 @@ CatalystX::DebugFilter - Provides configurable filtering of data that is logged
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
